/* eslint-disable no-restricted-imports */
import { CustomError } from "../utils/error";
import { isPublishAllowed } from "./check-if-can-publish";
import { deleteEntityOnWorkflowTable } from "./delete-entity";

export default () => {
	return async (ctx, next) => {
		try {
			const url = ctx.request.url;
			const splitUrl = url.split("/");
			const isContentManager = splitUrl[1] === "content-manager";
			if (!isContentManager) {
				return await next();
			}
			const isActionPublish =
				isContentManager &&
				splitUrl[splitUrl.length - 2] === "actions" &&
				splitUrl[splitUrl.length - 1] === "publish";
			const isActionDelete = isContentManager && ctx.request.method === "DELETE";

			if (isActionPublish) {
				const isCollectionTypes = splitUrl[2] === "collection-types";
				const slug = splitUrl[3];
				const collectionId = isCollectionTypes ? splitUrl[4] : "";
				await isPublishAllowed({ uid: slug, id: collectionId });
				return await next();
			}

			if (isActionDelete) {
				const isCollectionTypes = splitUrl[2] === "collection-types";
				const slug = splitUrl[3];
				const collectionId = isCollectionTypes ? splitUrl[4] : "";
				await deleteEntityOnWorkflowTable({ uid: slug, id: collectionId });
				return await next();
			}

			return await next();
		} catch (error) {
			let status = 500;
			let message = "some error occurred"; // Don't expose db error and other errors internal to code like undefined etc.

			if (error instanceof CustomError) {
				status = error.statusCode;
				message = error.message;
			}
			ctx.throw(status, `${message}`);
			return;
		}
	};
};
