/* eslint-disable no-restricted-imports */
import type { Strapi } from "@strapi/strapi";

import {
	EntryResponse,
	UserOrRole,
	capitalizeFirstLetter,
	mapRoleRelationsData,
	mapUserRelationsData,
	unlinkRelation
} from "../utils";

type Data = {
	approverId: number;
	workflowId: number;
	approverType: UserOrRole;
	entry: EntryResponse;
};
export default ({ strapi }: { strapi: Strapi }) => ({
	async update(payload: Data) {
		const { approverId, workflowId, approverType, entry } = payload;
		const previousApproverType = entry?.approverType;
		// unlink the previous type
		if (previousApproverType) {
			const type = capitalizeFirstLetter(previousApproverType);
			await unlinkRelation({ id: entry.id, link: `approverAs${type}`, type: `approverType` });
		}
		const approverTypeProp = { val: "approverType" };
		const updateApprover = await strapi.entityService?.update(
			"plugin::review-workflow.workflow",
			workflowId,
			{
				data: {
					[approverTypeProp.val]: `${approverType}`.toLowerCase(),
					[`approverAs${approverType}`]: approverId
				},
				populate: [`approverAs${approverType}`]
			}
		);
		let normalizeApprover;

		if (updateApprover?.assigneeAsUser) {
			normalizeApprover = mapUserRelationsData(updateApprover.assigneeAsUser);
		}

		if (updateApprover?.assigneeAsRole) {
			normalizeApprover = mapRoleRelationsData(updateApprover.assigneeAsRole);
		}
		return { ...updateApprover, [`approverAs${approverType}`]: normalizeApprover };
	}
});
