/* eslint-disable no-restricted-imports */
import type { Strapi } from "@strapi/strapi";

import {
	EntryResponse,
	UserOrRole,
	capitalizeFirstLetter,
	mapRoleRelationsData,
	mapUserRelationsData,
	unlinkRelation
} from "../utils";

type Data = {
	assigneeId: number;
	workflowId: number;
	assigneeType: UserOrRole;
	entry: EntryResponse;
};

export default ({ strapi }: { strapi: Strapi }) => ({
	async update(payload: Data) {
		const { assigneeId, workflowId, assigneeType, entry } = payload;
		const previousAssgineeType = entry?.assigneeType;

		if (previousAssgineeType) {
			const type = capitalizeFirstLetter(previousAssgineeType);
			await unlinkRelation({ id: entry.id, link: `assigneeAs${type}`, type: `assigneeType` });
		}
		const assigneeTypeProp = { val: "assigneeType" };
		const updateAssignee = await strapi.entityService?.update(
			"plugin::review-workflow.workflow",
			workflowId,
			{
				data: {
					[assigneeTypeProp.val]: `${assigneeType}`.toLowerCase(),
					[`assigneeAs${assigneeType}`]: assigneeId
				},
				populate: [`assigneeAs${assigneeType}`]
			}
		);

		let normalizeAssignee;

		if (updateAssignee?.assigneeAsUser) {
			normalizeAssignee = mapUserRelationsData(updateAssignee.assigneeAsUser);
		}

		if (updateAssignee?.assigneeAsRole) {
			normalizeAssignee = mapRoleRelationsData(updateAssignee.assigneeAsRole);
		}

		return { ...updateAssignee, [`assigneeAs${assigneeType}`]: normalizeAssignee };
	}
});
